==> vtigercrm-5.2.1.tgz: modules/Reports/language/nl_nl.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): Vertaling door Weltevree.org  www.weltevree.org
 ********************************************************************************/
/*********************************************************************************
 * $Header:  
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s):  Vertaling door Weltevree.org  www.weltevree.org
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Rapporten',
'LBL_MODULE_TITLE'=>'Rapporten: Home',
'LBL_CREATE_REPORT'=>'Maak rapport',
'LBL_CUSTOMIZE_REPORT'=>'Bewerk rapport',
'LBL_REP_BUTTON'=>'Maak nieuw rapport',
'LBL_REP_FOLDER_BUTTON'=>'Maak nieuwe rapport map',
'LBL_REP_FOLDER'=>'Rapport map',
'LBL_REP_FOLDER_DTLS'=>'Map details',
'LBL_REP_FOLDER_NAME'=>'Map naam:',
'LBL_REP_FOLDER_DESC'=>'Map omschrijving:',
'LBL_NEW_REP0_HDR1'=>'Selecteer een module voor elk nieuw rapport dat u wilt maken:',
'LBL_NEW_REP0_HDR2'=>'Selecteer gerelateerde module:',
'LBL_NEW_REP0_HDR3'=>'Notitie:',
'LBL_NEW_REP0_HDR4'=>'Rapport module en gerelateerde module kunnen niet meer worden gewijzgd',
'LBL_CONTINUE_BUTTON'=>'Ga verder',
'LBL_NEW_REP1_HDR1'=>'Zorg voor de volgende rapport informatie',
'LBL_SELECT_COLUMNS'=>'Selecteer kolom',
'LBL_SPECIFY_GROUPING'=>'Specificeer groep',
'LBL_COLUMNS_TO_TOTAL'=>'Kies een kolom voor de totalen',
'LBL_SPECIFY_CRITERIA'=>'Specificeer criteria',
'LBL_SAVERUN_BUTTON'=>'Opslaan en tonen',
'LBL_TABULAT_REPORT'=>'Tabular rapport',
'LBL_REPORT_TYPE_HDR1'=>'Tabular rapporten zijn de snelste en simpelste manier om uw informatie in lijsten te tonen.',
'LBL_SUMMARY_REPORT'=>'Verzamel rapport',
'LBL_REPORT_TYPE_HDR2'=>'Verzamelrapporten laten u ook subtotalen zien in de verzamelrapporten.',
'LBL_AVAILABLE_COLUMNS'=>'Beschikbare kolommen:',
'LBL_SELECTED_COLUMNS'=>'Geselecteerde kolommen:',
'LBL_ADD_BUTTON'=>'Toevoegen',
'LBL_COLUMNS'=>'Kolommen',
'LBL_COLUMNS_SUM'=>'Opgeteld',
'LBL_COLUMNS_AVERAGE'=>'Gemiddeld',
'LBL_COLUMNS_LOW_VALUE'=>'Laagste getal',
'LBL_COLUMNS_LARGE_VALUE'=>'Hoogste getal',
'LBL_NONE'=>'Geen',
'LBL_GROUPING_SORT'=>'Sorteer order:',
'LBL_GROUPING_SUMMARIZE'=>'Samenvatting informatie door:',
'LBL_GROUPING_THEN_BY'=>'en toen door:',
'LBL_GROUPING_FINALLY_BY'=>'en uiteindelijk door:',
'LBL_ADVANCED_FILTER'=>'Slimme filters',
'LBL_STANDARD_FILTER'=>'Standaard filters',
'LBL_SF_COLUMNS'=>'Kolom',
'LBL_SF_STARTDATE'=>'Startdatum',
'LBL_SF_ENDDATE'=>'Einddatum',
'LBL_AF_HDR1'=>'Specificeer zoek argumenten voor betere resulaten.',
'LBL_AF_HDR2'=>'U kunt verschillende argumenten invoeren in de derde kolom.',
'LBL_AF_HDR3'=>'U kunt tot 10 items invoeren, gescheiden door een komma.',
'LBL_FILTER_OPTIONS'=>'Filter opties',
'LBL_CUSTOMIZE_BUTTON'=>'Bewerk',
'LBL_EXPORTPDF_BUTTON'=>'Exporteer naar PDF',
'LBL_APPLYFILTER_BUTTON'=>'Filter aanzetten',
'LBL_GENERATED_Raport'=>'Genereer rapport',
'LBL_GRAND_TOTAL'=>'Totaal Generaal',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Exporteer naar Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Uw Profiel geeft u geen rechten om rapporten en modules te bekijken.',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Selecteer kolommen om rapporten te genereren',
'LBL_AVAILABLE_FIELDS'=>'Beschikbare velden',
'LBL_SELECTED_FIELDS'=>'Geselecteerde velden',
'LBL_CALCULATIONS'=>'Calculaties',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Selecteer kolommen voor totalen',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Selecteer filters om rapporten overzichtelijk te houden',
'LBL_SELECT_FILTERS'=>'Filters',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Selecteer kolommen voor groep rapporten',
'LBL_BACK_TO_REPORTS'=>'Terug naar rapporten',
'LBL_SELECT_ANOTHER_REPORT'=>'Selecteer een ander rapport',
'LBL_SELECT_COLUMN'=>'Selecteer kolom',
'LBL_SELECT_TIME'=>'Selecteer tijd',
'LBL_PRINT_REPORT'=>'Print rapport',
'LBL_CLICK_HERE'=>'Klik hier',
'LBL_TO_ADD_NEW_GROUP'=>'om een nieuwe groep toe te voegen',
'LBL_CREATE_NEW'=>'Maak nieuw',
'LBL_RELATIVE_MODULE'=>'Gerelateerde module',
'LBL_REPORT_TYPE'=>'Rapport type',
'LBL_REPORT_DETAILS'=>'Rapport details',
'LBL_TYPE_THE_NAME'=>'Type de naam',
'LBL_DESCRIPTION_FOR_REPORT'=>'Omschrijving van het rapport',
'LBL_REPORT_NAME'=>'Rapport naam',
'LBL_DESCRIPTION'=>'Omschrijving',
'LBL_TOOLS'=>'Gereedschap',
'LBL_AND'=>'en',
'LBL_ADD_NEW_GROUP'=>'Nieuwe groep toevoegen',
'LBL_REPORT_MODULE'=>'Rapport module',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'Selecteer gerelateerde module voor het rapport',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'Selecteer rapport type',
'LBL_TABULAR_FORMAT'=>'Tabular formaat',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>'Tabular rapporten zijn de snelste en simpelste manier om uw informatie in lijsten te tonen.',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Verzamelrapporten laten u ook subtotalen zien in de verzamelrapporten.',
'LBL_FILTERS'=>'Filters',
'LBL_MOVE_TO'=>'Verplaats naar',
'LBL_RENAME_FOLDER'=>'Verander map naam',
'LBL_DELETE_FOLDER'=>'Verwijder map',

'Account and Contact Reports'=>'Account en contact rapport',
'Lead Reports'=>'Lead rapport',
'Potential Reports'=>'Verkoop potentieel rapport',
'Activity Reports'=>'Activiteit rapport',
'HelpDesk Reports'=>'Ticket rapport',
'Product Reports'=>'product rapport',
'Quote Reports'=>'Offerte rapport',
'PurchaseOrder Reports'=>'Inkooporder rapport',
'SalesOrder Reports'=>'Verkooporder rapport', //Added for SO
'Invoice Reports'=>'Facturen rapport',
'Campaign Reports'=>'Campagne rapport', //Added for Campaigns 
'Contacts by Accounts'=>'Contacten bij accounts',
'Contacts without Accounts'=>'Contacten zonder accounts',
'Contacts by Potentials'=>'Contacten bij verkoop potentieel',
'Contacts related to Accounts'=>'Contacten gerelateerd aan accounts',
'Contacts not related to Accounts'=>'Contacten niet gerelateerd aan accounts',
'Contacts related to Potentials'=>'Contacten gerelateerd aan verkoop potentieel',
'Lead by Source'=>'Lead per bron',
'Lead Status Report'=>'Lead status rapport',
'Potential Pipeline'=>'Verkoop potentieel Pipeline',
'Closed Potentials'=>'Gesloten verkoop potentieel',
'Potential that have Won'=>'Gewonnen verkoop potentieel',
'Tickets by Products'=>'Tickets per product',
'Tickets by Priority'=>'Tickets per prioriteit',
'Open Tickets'=>'Open tickets',
'Tickets related to Products'=>'Tickets gerelateerd aan producten',
'Tickets that are Open'=>'Tickets die open zijn',
'Product Details'=>'Product details',
'Products by Contacts'=>'Producten per contact',
'Product Detailed Report'=>'Gedetailleerd product rapport',
'Products related to Contacts'=>'producten gerelateerd aan contacten',
'Open Quotes'=>'Open offertes',
'Quotes Detailed Report'=>'Gedetailleerd factuur rapport',
'Quotes that are Open'=>'Offertes die open zijn',
'PurchaseOrder by Contacts'=>'Inkooporder van contacten',
'PurchaseOrder Detailed Report'=>'Gedetailleerd inkooporder rapport',
'PurchaseOrder related to Contacts'=>'Inkooporder gerelateerd aan contacten',
'Invoice Detailed Report'=>'Gedetailleerd factuur rapport',
'Last Month Activities'=>'Activiteiten van de vorige maand',
'This Month Activities'=>'Activiteiten van deze maand',
'Campaign Expectations and Actuals'=>'Campagne verwachting + actueel', //Added for Campaigns
'SalesOrder Detailed Report'=>'Gedetailleerd verkooporder rapport', //Added for SO

'LBL_DELETE'=>'Verwijder',
'Create_Reports'=>'Maak rapport',
'Create_New_Folder'=>'Maak een nieuwe map',
'Move_Reports'=>'Verhuis rapport',
'Delete_Report'=>'Verwijder rapport', 

'Custom'=>'Verander',
'Previous FY'=>'Vorige FY', 
'Current FY'=>'Huidig FY',
'Next FY'=>'Volgende FY',
'Previous FQ'=>'Vorige FQ',
'Current FQ'=>'Huidige FQ',
'Next FQ'=>'Volgende FQ',
'Yesterday'=>'Gisteren',
'Today'=>'Vandaag',
'Tomorrow'=>'Morgen',
'Last Week'=>'Verleden week',
'Current Week'=>'Deze week',
'Next Week'=>'Volgende week',
'Last Month'=>'Vorige maand',
'Current Month'=>'Deze maand',
'Next Month'=>'Volgende maand',
'Last 7 Days'=>'Laatste 7 dagen',
'Last 30 Days'=>'Laatste 30 dagen',
'Last 60 Days'=>'Laatste 60 dagen',
'Last 90 Days'=>'Laatste 90 dagen',
'Last 120 Days'=>'Laatste 120 dagen',
'Next 7 Days'=>'Volgende 7 dagen',
'Next 30 Days'=>'Volgende 30 dagen',
'Next 60 Days'=>'Volgende 60 dagen',
'Next 90 Days'=>'Volgende 90 dagen',
'Next 120 Days'=>'Volgende 120 dagen',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'vtiger CRM - Rapport aanmaken',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'vtiger -  Print Rapport',
'NO_FILTER_SELECTED' => 'Geen filter geselecteerd',

'LBL_GENERATE_NOW'=>'Genereer nu',
'Totals'=>'Totalen',
'SUM'=>'Totaal',
'AVG'=>'Gemiddeld',
'MAX'=>'MAX',
'MIN'=>'MIN',
'LBL_CUSTOM_REPORTS'=>'Eigen rapport',

'ticketid'=>'Ticket Id',
'NO_COLUMN'=>'Geen totaal kolommen aanwezig',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'Het rapport wat u zoekt is verwijderd.',

//Added for Reports
'LBL_SHARING'=>'Delen',
'SELECT_FILTER_TYPE'=>'Selecteer Report Type',
'LBL_USERS'=>'Gebruikerss',
'LBL_GROUPS'=>'Groepen',
'LBL_SELECT_FIELDS'=>'Selecteer Velden',
'LBL_MEMBERS'=>'Leden',
'LBL_RELATED_FIELDS'=>'Gerelateerde Velden',
'LBL_NO_ACCESS'=>' Toegang Geweigerd voor module(s) ',
'LBL_NOT_ACTIVE'=>' Toegang Geweigerd voor module(s) ',
'LBL_PERM_DENIED'=>' Toegang Geweigerd voor module(s) voor Rapport(en): ',
'LBL_FLDR_NOT_EMPTY'=>' De Map die u probeert te verwijderen is niet Leeg, Verplaats of Verwijder de rapporten eerst.',
'NO_REL_MODULES'=>'Geen Gerelateerde Module voor de geselecteerde Module',
'LBL_REPORT_GENERATION_FAILED'=>'Rapport maken mislukt!',
)

?>

==> vtigercrm-5.4.0.tgz: modules/Reports/language/nl_nl.lang.php <==
<?php

/*******************************************************************************
 * The contents of this file are subject to the following licences:
 * - SugarCRM Public License Version 1.1.2 http://www.sugarcrm.com/SPL
 * - vtiger CRM Public License Version 1.0 
 * You may not use this file except in compliance with the License
 * Software distributed under the License is distributed on an  "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is: SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * Portions created by vtiger are Copyright (C) vtiger.
 * Portions created by Vicus are Copyright (C) Vicus.
 * All Rights Reserved.
 * Feel free to use / redistribute these languagefiles under the VPL 1.0.
 * This translations is based on earlier work of: 
 * - IT-Online.nl <www.it-online.nl>
 * - Weltevree.org <www.Weltevree.org>
 ********************************************************************************/

/*******************************************************************************
 * Vicus eBusiness Solutions Version Control
 * @package 	NL-Dutch
 * Description	Dutch language pack for vtiger CRM version 5.3.x
 * @author	$Author: luuk $
 * @version 	$Revision: 1.2 $ $Date: 2011/11/14 17:07:26 $
 * @source	$Source: /var/lib/cvs/vtiger530/Dutch/modules/Reports/language/nl_nl.lang.php,v $
 * @copyright	Copyright (c)2005-2011 Vicus eBusiness Solutions bv <info@vicus.nl>
 * @license	vtiger CRM Public License Version 1.0 (by definition)
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Rapporten',
'LBL_MODULE_TITLE'=>'Rapporten: Home',
'LBL_CREATE_REPORT'=>'Maak rapport',
'LBL_CUSTOMIZE_REPORT'=>'Bewerk rapport',
'LBL_REP_BUTTON'=>'Maak nieuw rapport',
'LBL_REP_FOLDER_BUTTON'=>'Maak nieuwe rapport map',
'LBL_REP_FOLDER'=>'Rapport map',
'LBL_REP_FOLDER_DTLS'=>'Map details',
'LBL_REP_FOLDER_NAME'=>'Map naam:',
'LBL_REP_FOLDER_DESC'=>'Map omschrijving:',
'LBL_NEW_REP0_HDR1'=>'Selecteer een module voor elk nieuw rapport dat u wilt maken:',
'LBL_NEW_REP0_HDR2'=>'Selecteer gerelateerde module:',
'LBL_NEW_REP0_HDR3'=>'Notitie:',
'LBL_NEW_REP0_HDR4'=>'Rapport module en gerelateerde module kunnen niet meer worden gewijzgd',
'LBL_CONTINUE_BUTTON'=>'Ga verder',
'LBL_NEW_REP1_HDR1'=>'Zorg voor de volgende rapport informatie',
'LBL_SELECT_COLUMNS'=>'Selecteer kolom',
'LBL_SPECIFY_GROUPING'=>'Specificeer groep',
'LBL_COLUMNS_TO_TOTAL'=>'Kies een kolom voor de totalen',
'LBL_SPECIFY_CRITERIA'=>'Specificeer criteria',
'LBL_SAVERUN_BUTTON'=>'Opslaan en tonen',
'LBL_TABULAT_REPORT'=>'Tabular rapport',
'LBL_REPORT_TYPE_HDR1'=>'Tabular rapporten zijn de snelste en simpelste manier om uw informatie in lijsten te tonen.',
'LBL_SUMMARY_REPORT'=>'Verzamel rapport',
'LBL_REPORT_TYPE_HDR2'=>'Verzamelrapporten laten u ook subtotalen zien in de verzamelrapporten.',
'LBL_AVAILABLE_COLUMNS'=>'Beschikbare kolommen:',
'LBL_SELECTED_COLUMNS'=>'Geselecteerde kolommen:',
'LBL_ADD_BUTTON'=>'Toevoegen',
'LBL_COLUMNS'=>'Kolommen',
'LBL_COLUMNS_SUM'=>'Opgeteld',
'LBL_COLUMNS_AVERAGE'=>'Gemiddeld',
'LBL_COLUMNS_LOW_VALUE'=>'Laagste getal',
'LBL_COLUMNS_LARGE_VALUE'=>'Hoogste getal',
'LBL_NONE'=>'Geen',
'LBL_GROUPING_SORT'=>'Sorteer order:',
'LBL_GROUPING_SUMMARIZE'=>'Samenvatting informatie door:',
'LBL_GROUPING_THEN_BY'=>'en toen door:',
'LBL_GROUPING_FINALLY_BY'=>'en uiteindelijk door:',
'LBL_ADVANCED_FILTER'=>'Geavanceerde filters',
'LBL_STANDARD_FILTER'=>'Standaard filters',
'LBL_SF_COLUMNS'=>'Kolom',
'LBL_SF_STARTDATE'=>'Startdatum',
'LBL_SF_ENDDATE'=>'Einddatum',
'LBL_AF_HDR1'=>'Specificeer zoek argumenten voor betere resulaten.',
'LBL_AF_HDR2'=>'U kunt verschillende argumenten invoeren in de derde kolom.',
'LBL_AF_HDR3'=>'U kunt tot 10 items invoeren, gescheiden door een komma.',
'LBL_FILTER_OPTIONS'=>'Filter opties',
'LBL_CUSTOMIZE_BUTTON'=>'Bewerk',
'LBL_EXPORTPDF_BUTTON'=>'Exporteer naar PDF',
'LBL_APPLYFILTER_BUTTON'=>'Filter aanzetten',
'LBL_GENERATED_Raport'=>'Genereer rapport',
'LBL_GRAND_TOTAL'=>'Totaal',

//Added for 4.2 Patch I
'LBL_EXPORTXL_BUTTON'=>'Exporteer naar Excel',

//Added for 5 Beta
'LBL_NO_PERMISSION'=>'Uw profiel geeft u geen rechten om rapporten en modules te bekijken.',
'LBL_SELECT_COLUMNS_TO_GENERATE_REPORTS'=>'Selecteer kolommen om rapporten te genereren',
'LBL_AVAILABLE_FIELDS'=>'Beschikbare velden',
'LBL_SELECTED_FIELDS'=>'Geselecteerde velden',
'LBL_CALCULATIONS'=>'Calculaties',
'LBL_SELECT_COLUMNS_TO_TOTAL'=>'Selecteer kolommen voor totalen',
'LBL_SELECT_FILTERS_TO_STREAMLINE_REPORT_DATA'=>'Selecteer filters om rapporten overzichtelijk te houden',
'LBL_SELECT_FILTERS'=>'Filters',
'LBL_SELECT_COLUMNS_TO_GROUP_REPORTS'=>'Selecteer kolommen voor groep rapporten',
'LBL_BACK_TO_REPORTS'=>'Terug naar rapporten',
'LBL_SELECT_ANOTHER_REPORT'=>'Selecteer een ander rapport',
'LBL_SELECT_COLUMN'=>'Selecteer kolom',
'LBL_SELECT_TIME'=>'Selecteer tijd',
'LBL_PRINT_REPORT'=>'Print rapport',
'LBL_CLICK_HERE'=>'Klik hier',
'LBL_TO_ADD_NEW_GROUP'=>'Nieuwe groep toevoegen',
'LBL_CREATE_NEW'=>'Maak nieuw',
'LBL_RELATIVE_MODULE'=>'Gerelateerde module',
'LBL_REPORT_TYPE'=>'Rapport type',
'LBL_REPORT_DETAILS'=>'Rapport details',
'LBL_TYPE_THE_NAME'=>'Type de naam',
'LBL_DESCRIPTION_FOR_REPORT'=>'Omschrijving van het rapport',
'LBL_REPORT_NAME'=>'Rapportnaam',
'LBL_DESCRIPTION'=>'Omschrijving',
'LBL_TOOLS'=>'Gereedschap',
'LBL_AND'=>'en',
'LBL_ADD_NEW_GROUP'=>'Nieuwe groep toevoegen',
'LBL_REPORT_MODULE'=>'Rapport module',
'LBL_SELECT_RELATIVE_MODULE_FOR_REPORT'=>'Selecteer gerelateerde module voor het rapport',
'LBL_SELECT_REPORT_TYPE_BELOW'=>'Selecteer rapport type',
'LBL_TABULAR_FORMAT'=>'Tabular formaat',
'LBL_TABULAR_REPORTS_ARE_SIMPLEST'=>'Tabular rapporten zijn de snelste en simpelste manier om uw informatie in lijsten te tonen.',
'LBL_SUMMARY_REPORT_VIEW_DATA_WITH_SUBTOTALS'=>'Verzamelrapporten laten u ook subtotalen zien in de verzamelrapporten.',
'LBL_FILTERS'=>'Filters',
'LBL_MOVE_TO'=>'Verplaats naar',
'LBL_RENAME_FOLDER'=>'Wijzig naam',
'LBL_DELETE_FOLDER'=>'Verwijder',

'Account and Contact Reports'=>'Account en contact rapport',
'Lead Reports'=>'Lead rapport',
'Potential Reports'=>'Verkoopkans rapport',
'Activity Reports'=>'Activiteit rapport',
'HelpDesk Reports'=>'Ticket rapport',
'Product Reports'=>'Product rapport',
'Quote Reports'=>'Offerte rapport',
'PurchaseOrder Reports'=>'Inkooporder rapport',
'SalesOrder Reports'=>'Verkooporder rapport', //Added for SO
'Invoice Reports'=>'Factuur rapport',
'Campaign Reports'=>'Campagne rapport', //Added for Campaigns 
'Contacts by Accounts'=>'Contacten bij accounts',
'Contacts without Accounts'=>'Contacten zonder accounts',
'Contacts by Potentials'=>'Contacten bij verkoopkansen',
'Contacts related to Accounts'=>'Contacten gerelateerd aan accounts',
'Contacts not related to Accounts'=>'Contacten niet gerelateerd aan accounts',
'Contacts related to Potentials'=>'Contacten gerelateerd aan verkoopkansen',
'Lead by Source'=>'Lead per bron',
'Lead Status Report'=>'Lead status rapport',
'Potential Pipeline'=>'Verkoopkans Pipeline',
'Closed Potentials'=>'Gesloten verkoopkansen',
'Potential that have Won'=>'Gewonnen verkoopkansen',
'Tickets by Products'=>'Tickets per Product',
'Tickets by Priority'=>'Tickets per prioriteit',
'Open Tickets'=>'Open tickets',
'Tickets related to Products'=>'Tickets gerelateerd aan Producten',
'Tickets that are Open'=>'Tickets die open zijn',
'Product Details'=>'Product details',
'Products by Contacts'=>'Products per contact',
'Product Detailed Report'=>'Gedetailleerd Product rapport',
'Products related to Contacts'=>'Producten gerelateerd aan contacten',
'Open Quotes'=>'Open offertes',
'Quotes Detailed Report'=>'Gedetailleerd factuur rapport',
'Quotes that are Open'=>'Offertes die open zijn',
'PurchaseOrder by Contacts'=>'Inkooporder van contacten',
'PurchaseOrder Detailed Report'=>'Gedetailleerd inkooporder rapport',
'PurchaseOrder related to Contacts'=>'Inkooporder gerelateerd aan contacten',
'Invoice Detailed Report'=>'Gedetailleerd factuur rapport',
'Last Month Activities'=>'Activiteiten verleden maand',
'This Month Activities'=>'Activiteiten van deze maand',
'Campaign Expectations and Actuals'=>'Campagne verwachting + actueel', //Added for Campaigns
'SalesOrder Detailed Report'=>'Gedetailleerd verkooporder rapport', //Added for SO

'LBL_DELETE'=>'Verwijder',
'Create_Reports'=>'Maak rapport',
'Create_New_Folder'=>'Maak een nieuwe map',
'Move_Reports'=>'Verhuis rapport',
'Delete_Report'=>'Verwijder rapport', 

'Custom'=>'Op maat',
'Previous FY'=>'Vorige FY', 
'Current FY'=>'Huidig FY',
'Next FY'=>'Volgende FY',
'Previous FQ'=>'Vorige FQ',
'Current FQ'=>'Huidige FQ',
'Next FQ'=>'Volgende FQ',
'Yesterday'=>'Gisteren',
'Today'=>'Vandaag',
'Tomorrow'=>'Morgen',
'Last Week'=>'Verleden week',
'Current Week'=>'Deze week',
'Next Week'=>'Volgende week',
'Last Month'=>'Vorige maand',
'Current Month'=>'Deze maand',
'Next Month'=>'Volgende maand',
'Last 7 Days'=>'Laatste 7 dagen',
'Last 30 Days'=>'Laatste 30 dagen',
'Last 60 Days'=>'Laatste 60 dagen',
'Last 90 Days'=>'Laatste 90 dagen',
'Last 120 Days'=>'Laatste 120 dagen',
'Next 7 Days'=>'Volgende 7 dagen',
'Next 30 Days'=>'Volgende 30 dagen',
'Next 60 Days'=>'Volgende 60 dagen',
'Next 90 Days'=>'Volgende 90 dagen',
'Next 120 Days'=>'Volgende 120 dagen',
'TITLE_VTIGERCRM_CREATE_REPORT' => 'vtiger CRM - Rapport aanmaken',
'TITLE_VTIGERCRM_PRINT_REPORT' => 'vtiger -  Print Rapport',
'NO_FILTER_SELECTED' => 'Geen filter geselecteerd',

'LBL_GENERATE_NOW'=>'Genereer nu',
'Totals'=>'Totalen',
'SUM'=>'Totaal',
'AVG'=>'Gemiddeld',
'MAX'=>'MAX',
'MIN'=>'MIN',
'LBL_CUSTOM_REPORTS'=>'Eigen rapport',

'ticketid'=>'Ticket Id',
'NO_COLUMN'=>'Geen totaal kolommen aanwezig',

// Added/Updated for vtiger CRM 5.0.4
'LBL_REPORT_DELETED' => 'Het rapport dat u wilt bekijken is verwijderd.',

//Added for Reports
'LBL_SHARING'=>'Combineren',
'SELECT_FILTER_TYPE'=>'Selecteer Rapporttype',
'LBL_USERS'=>'Gebruikers',
'LBL_GROUPS'=>'Groepen',
'LBL_SELECT_FIELDS'=>'Selecteer Velden',
'LBL_MEMBERS'=>'Onderdelen',
'LBL_RELATED_FIELDS'=>'Gerelateerde Velden',
'LBL_NO_ACCESS'=>' Toegang geweigerd voor module(s) ',
'LBL_NOT_ACTIVE'=>' Toegang geweigerd voor module(s) ',
'LBL_PERM_DENIED'=>' Toegang geweigerd voor Rapport(en): ',
'LBL_FLDR_NOT_EMPTY'=>'De map die u wilt wijzigen is niet leeg, eerst leegmaken.',
'NO_REL_MODULES'=>'Er zijn modules om mee te combineren',
'LBL_REPORT_GENERATION_FAILED'=>'Het rapport kan niet worden gemaakt!',

// since vtiger CRM 5.3 by Vicus
'LBL_SHARING_TYPE'=>'Deel Type',
'LBL_SELECT_REPORT_TYPE_TO_CONTROL_ACCESS'=>'Selecteer Type om toegang tot het rapport te regelen',
'LBL_ACTION' => 'Actie',
'LBL_VIEW_DETAILS' => 'Toon Details',
'LBL_SHOW_STANDARD_FILTERS' => 'Toon Standaard Filters',
'LBL_YEAR' => 'Jaar',
'LBL_MONTH'=> 'Maand',
'LBL_QUARTER'=> 'Kwartaal',
'LBL_NONE'=> 'Geen',

'LBL_ROLES'=>'Rollen',
'LBL_ROLES_SUBORDINATES'=>'Rollen en ondergeschikten',
'LBL_SCHEDULE_EMAIL'=>'Inplannen e-mail',
'LBL_SCHEDULE_EMAIL_DESCRIPTION'=>'Plan Rapport in om naar de geselecteerde ontvangers via e-mail te verzenden op regelmatige intervallen.',
'LBL_USERS_AVAILABEL'=> 'Ontvangers',
'LBL_REPORT_FORMAT_PDF'=> 'PDF',
'LBL_REPORT_FORMAT_EXCEL'=> 'EXCEL',
'LBL_REPORT_FORMAT_BOTH'=> 'Beiden',
'LBL_REPORT_FORMAT'=> 'Rapportformaat',
'LBL_USERS_SELECTED'=>'Geselecteerde Ontvangers',
'LBL_SELECT'=>'Selecteer',
'Hourly'=>'Elk uur',
'Daily'=>'Dagelijks',
'Weekly'=>'Wekelijks',
'BiWeekly'=>'Twee-Wekelijks',
'Monthly'=>'Maandelijks',
'Annually'=>'Jaarlijks',
'LBL_SCHEDULE_REPORT'=>'Plan Report',
'LBL_SCHEDULE_FREQUENCY'=>'Frequentie',
'OPTION_SCHEDULE_EMAIL_CHOOSE'=>'Kies ..... ',
'LBL_SCHEDULE_EMAIL_TIME'=>'Tijd',
'LBL_SCHEDULE_EMAIL_DOW'=>'DOW',
'LBL_SCHEDULE_EMAIL_DAY'=>'Dag',
'LBL_SCHEDULE_EMAIL_MONTH'=>'Maand',
'WEEKDAY_STRINGS' => array('Zondag','Maandag','Dinsdag','Woensdag','Donderdag','Vrijdag','Zaterdag'),
'MONTH_STRINGS' => array('Januari','Februari','Maart','April','Mei','Juni','Juli','Augustus','September','Oktober','November','December'),

'LBL_AUTO_GENERATED_REPORT_EMAIL' => 'Dit is een automatisch gegenereerde e-mail die is verzonden middels een gepland rapport.',
'LBL_TIME_FORMAT_MSG' => 'hh:mm (24 uurs formaat)',

'LBL_SAVE_REPORT' => 'Opslaan',
'LBL_SAVE_REPORT_AS' => 'Sla Rapport op als...',

)

?>
